// Copyright (C) 2004-2022, Stefan Kanthak <stefan.kanthak@nexgo.de>

// https://msdn.microsoft.com/en-us/library/4141z1cx.aspx

#pragma once

#ifndef __RESOURCE_H__
#define __RESOURCE_H__

// https://msdn.microsoft.com/en-us/library/ee264326.aspx
// https://msdn.microsoft.com/en-us/library/ee264325.aspx
// https://msdn.microsoft.com/en-us/library/ee264324.aspx

typedef	struct	_MUI_RESOURCE
{
	DWORD	dwSignature;		// = 0xFECDFECDUL
	DWORD	dwSize;			// size of "MUI" resource configuration data
	DWORD	dwVersion;		// = 0x00010000UL
	DWORD	dwUnknown;
	DWORD	dwFileType;		// = 0x00000011UL: LN, language-neutral main file
					// = 0x00000012UL: MUI, language-specific satellite file
	DWORD	dwSystemAttributes;
	DWORD	dwFallbackLocation;	// = 0x00000000UL: none
					// = 0x00000001UL: internal
					// = 0x00000002UL: external
	BYTE	bServiceChecksum[16];
	BYTE	bMainChecksum[16];
	DWORD	dwReserved[6];
	DWORD	dwTypeNameMainOffset;	// offset and size of named resource types
	DWORD	dwTypeNameMainSize;	//  in main file (MULTI_SZ list)
	DWORD	dwTypeIDMainOffset;	// offset and size of unnamed resource types
	DWORD	dwTypeIDMainSize;	//  in main file (DWORD array)
	DWORD	dwTypeNameMUIOffset;	// offset and size of named resource types
	DWORD	dwTypeNameMUISize;	//  in satellite file (MULTI_SZ list)
	DWORD	dwTypeIDMUIOffset;	// offset and size of unnamed resource types
	DWORD	dwTypeIDMUISize;	//  in satellite file (DWORD array)
	DWORD	dwLanguageNameOffset;	// offset and size of language string
	DWORD	dwLanguageNameSize;
	DWORD	dwFallbackNameOffset;	// offset and size of (ultimate) fallback
	DWORD	dwFallbackNameSize;	//  language string
	DWORD	dwPadding;
//	DWORD	dwData[0];
} MUI_RESOURCE, *LPMUI_RESOURCE, *PMUI_RESOURCE;

#define MUI_RESOURCE_SIGNATURE		0xFECDFECDUL
#define MUI_RESOURCE_FILETYPE_MAIN	0x00000011UL
#define MUI_RESOURCE_FILETYPE_SATELLITE	0x00000012UL
#define MUI_RESOURCE_FALLBACK_NONE	0x00000000UL
#define MUI_RESOURCE_FALLBACK_INTERNAL	0x00000001UL
#define MUI_RESOURCE_FALLBACK_EXTERNAL	0x00000002UL
#endif // __RESOURCE_H__
